@@ -10,8 +10,6 @@
     clippy::checked_conversions,
     clippy::dbg_macro,
     clippy::debug_assert_with_mut_call,
-    clippy::disallowed_method,
-    clippy::disallowed_type,
     clippy::doc_markdown,
     clippy::empty_enum,
     clippy::enum_glob_use,
@@ -145,7 +143,7 @@ impl From<cm::Package> for Krate {
         // Fix the license field as cargo used to allow the
         // invalid / separator
         if let Some(ref mut lf) = pkg.license {
-            *lf = lf.replace("/", " OR ");
+            *lf = lf.replace('/', " OR ");
         }
 
         Self(pkg)
